local L = LibStub("AceLocale-3.0"):GetLocale("SmexyMats");
local SmexyMats = SmexyMats;

function SmexyMats:trim(s)
	return SmexyMats:rtrim(SmexyMats:ltrim(s));
end;

function SmexyMats:ltrim(s)
	return (s:gsub("^%s*", ""));
end;

function SmexyMats:rtrim(s)
	local n = #s;
	while n > 0 and s:find("^%s", n) do 	
		n = n - 1;
	end;
	return s:sub(1, n);
end;

function SmexyMats:Gear_ExpackID(obj)
	--Try to get exPackID from Armor, Relics, Weapons.
	if (obj.ff == "Armor") or (obj.ff == "Weapon") or (obj.gg == "Artifact Relic") then 
		return tonumber(obj.oo), SmexyMats.ExPacks[obj.oo].color;
	end;
	if (obj.ff == L["Armor"]) or (obj.ff == L["Weapon"]) or (obj.gg == L["Artifact Relic"]) then 
		return tonumber(obj.oo), SmexyMats.ExPacks[obj.oo].color;
	end;
	--Default Return
	return -1, SmexyMats.ExPacks[-1].color;
end;

function SmexyMats.rgbToHex(rgb)
	local hexadecimal = '';
	for key, value in pairs(rgb) do
		local hex = '';
		while(value > 0)do
			local index = math.fmod(value, 16) + 1;
			value = math.floor(value / 16);
			hex = string.sub('0123456789ABCDEF', index, index) .. hex;		
		end;
		if(string.len(hex) == 0)then
			hex = '00';
		elseif(string.len(hex) == 1)then
			hex = '0' .. hex;
		end;
		hexadecimal = hexadecimal .. hex;
	end;
	return hexadecimal;
end;

SmexyMats.Colors = {
	CLASSIC		= "|cFFE6CC80",
	TBC			= "|cFF1EFF00",
	WOTLK		= "|cFF66ccff",
	CATA		= "|cFFff3300",
	MOP			= "|cFF00FF96",
	WOD			= "|cFFff8c1a",
	LEGION		= "|cFFA335EE",

	yellow 		= "|cFFFFFF00",
	white 		= "|cFFFFFFFF",
	-- rarity : http://wow.gamepedia.com/Quality
	common 		= "|cFFFFFFFF",
	uncommon 	= "|cFF1EFF00",
	rare 		= "|cFF0070DD",
	epic 		= "|cFFA335EE",
	legendary 	= "|cFFFF8000",
	artifact 	= "|cFFE6CC80",
	wowtoken	= "|cFF00CCFF",
	-- classes : http://wow.gamepedia.com/Class_colors
	DeathKnight = "|cFFC41F3B",
	DemonHunter = "|cFFA330C9",
	Druid 		= "|cFFFF7D0A",
	Hunter 		= "|cFFABD473",
	Mage 		= "|cFF69CCF0",
	Monk 		= "|cFF00FF96",
	Paladin 	= "|cFFF58CBA",
	Priest 		= "|cFFFFFFFF",
	Rogue 		= "|cFFFFF569",
	Shaman 		= "|cFF0070DE",
	Warlock 	= "|cFF9482C9",
	Warrior 	= "|cFFC79C6E",
};

SmexyMats.ExPacks = {
	[-1] = {
		name = L["Unknown"],
		color = SmexyMats.Colors.white,
		},
	[0]  = {
		name = L["Classic"],
		color = SmexyMats.Colors.CLASSIC,
		},
	[1]  = {
		name = L["The Burning Crusade"],
		color = SmexyMats.Colors.TBC,
		},
	[2]  = {
		name = L["Wrath of the Lich King"],
		color = SmexyMats.Colors.WOTLK,
		},
	[3]  = {
		name = L["Cataclysm"],
		color = SmexyMats.Colors.CATA,
		},
	[4]  = {
		name = L["Mists of Pandaria"],
		color = SmexyMats.Colors.MOP,
		},
	[5]  = {
		name = L["Warlords of Draenor"],
		color = SmexyMats.Colors.WOD,
		},
	[6]  = {
		name = L["Legion"],
		color = SmexyMats.Colors.LEGION,
		},
};

SmexyMats.Profs = {
	[-2]	= L["PvP"],
	[-1]	= L["Vendor"],
	[0.1]	= L["Zone Drop"],
	[0.2]	= L["Missions(WoD)"],
	[0.3]	= L["Missions(Legion)"],
	[0]		= L["World Drop"],
	[1]   	= L["Alchemy"],
	[1.5] 	= L["Alchemy, Transmutation"],
	[2]   	= L["Archaeology"],
	[3]   	= L["Blacksmithing"],
	[4]   	= L["Cooking"],
	[5]   	= L["Enchanting"],
	[5.5] 	= L["Enchanting, Disenchanting"],
	[6]   	= L["Engineering"],
	[7]   	= L["First Aid"],
	[8]   	= L["Fishing"],
	[9]   	= L["Herbalism"],
	[10]  	= L["Inscription"],
	[10.5]	= L["Inscription, Milling"],
	[11]  	= L["Jewelcrafting"],
	[11.5] 	= L["Jewelcrafting, Prospecting"],
	[12]  	= L["Leatherworking"],
	[13]  	= L["Mining"],
	[13.5]  = L["Mining, Smelting"],
	[14]  	= L["Skinning"],
	[15]  	= L["Tailoring"],
};